@@ -54,7 +54,6 @@ import javax.swing.JTextField;
 import javax.swing.JTree;
 import javax.swing.KeyStroke;
 import javax.swing.SwingConstants;
-import javax.swing.SwingUtilities;
 import javax.swing.WindowConstants;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
@@ -472,10 +471,10 @@ public class FindUnlinkedFilesDialog extends JDialog {
                             } else {
                                 message = Localization.lang("%0 files found", Integer.toString(counter));
                             }
-                            SwingUtilities.invokeLater(() -> progressBarSearching.setString(message));
+                            progressBarSearching.setString(message);
                         }
                     });
-            SwingUtilities.invokeLater(() -> searchFinishedHandler(rootNode));
+            searchFinishedHandler(rootNode);
         });
 
     }
@@ -532,14 +531,12 @@ public class FindUnlinkedFilesDialog extends JDialog {
                         @Override
                         public void stateChanged(ChangeEvent e) {
                             counter++;
-                            SwingUtilities.invokeLater(() -> {
-                                progressBarImporting.setValue(counter);
-                                progressBarImporting.setString(Localization.lang("%0 of %1", Integer.toString(counter),
-                                        Integer.toString(progressBarImporting.getMaximum())));
-                            });
+                            progressBarImporting.setValue(counter);
+                            progressBarImporting.setString(Localization.lang("%0 of %1", Integer.toString(counter),
+                                    Integer.toString(progressBarImporting.getMaximum())));
                         }
                     }, errors);
-            SwingUtilities.invokeLater(() -> importFinishedHandler(errors));
+            importFinishedHandler(errors);
         });
     }
 
